AMapGeoFenceAddStatusModel class

Properties

customID String?
与围栏关联的自有业务ID
getter/setter pair
errorCode int?
错误码 ios AMapGeoFenceErrorUnknown = 1, ///< 未知错误 AMapGeoFenceErrorInvalidParameter = 2, ///< 参数错误 AMapGeoFenceErrorFailureConnection = 3, ///< 网络连接异常 AMapGeoFenceErrorFailureAuth = 4, ///< 鉴权失败 AMapGeoFenceErrorNoValidFence = 5, ///< 无可用围栏 AMapGeoFenceErroFailureLocating = 6, ///< 定位错误 AMapGeoFenceErroFailureFullAccuracyLocating = 7, ///< 精确定位错误 android public static final int ADDGEOFENCE_SUCCESS = 0; public static final int ERROR_CODE_INVALID_PARAMETER = 1; ///< 错误码:参数错误 public static final int ERROR_CODE_FAILURE_CONNECTION = 4; ///< 错误码:网络连接异常 public static final int ERROR_CODE_FAILURE_PARSER = 5; ///< 错误码:解析数据失败(有可能是连接的需要登录的网络但是没有登录) public static final int ERROR_CODE_FAILURE_AUTH = 7; ///< 错误码:鉴权失败 public static final int ERROR_CODE_UNKNOWN = 8; ///< 错误码:其他未知错误 public static final int ERROR_NO_VALIDFENCE = 16; ///< 错误码:无可用地理围栏 public static final int ERROR_CODE_EXISTS = 17; ///< 错误码: 相同的围栏已经存在,无需重复添加 当地理围栏的customID,半径,周边点(多边形),中心点坐标(圆形)这几个属性完全一致时,则认为是相同围栏
getter/setter pair
fenceList List<AMapGeoFenceModel>
围栏列表
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited