AMapLocationProtocol enum
android 定位协议,目前支持二种定位协议 http协议: 在这种定位协议下,会使用http请求定位 https协议: 在这种定位协议下,会使用https请求定位
Values
- http → const AMapLocationProtocol
- https → const AMapLocationProtocol
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AMapLocationProtocol> - A constant List of the values in this enum, in order of their declaration.