AMapPoiModel class

Constructors

AMapPoiModel({required String keyword, required String poiType, required String city, required int size, required String customID})

Properties

city String
POI所在的城市名称 (北京)
final
customID String
与围栏关联的自有业务ID
final
hashCode int
The hash code for this object.
no setterinherited
keyword String
POI关键字 (北京大学)
final
poiType String
POI类型 (高等院校)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
范围大小
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited