CoordType enum

Inheritance
Available extensions

Values

baidu → const CoordType

百度坐标

mapBar → const CoordType

图吧坐标

mapAbc → const CoordType

图盟坐标

sosoMap → const CoordType

搜搜坐标

aliYun → const CoordType

阿里云

google → const CoordType

谷歌坐标

gps → const CoordType

GPS原始坐标

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CoordType>
A constant List of the values in this enum, in order of their declaration.