FlAMap class

Constructors

FlAMap()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAMapKey({required String iosKey, required String androidKey, bool isAgree = true, bool isContains = true, bool isShow = true}) Future<bool>
设置ios&android的key
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlAMap
no setter