GenFenceStatus enum

Inheritance
Available extensions

Values

none → const GenFenceStatus

未知

inside → const GenFenceStatus

在范围内

outside → const GenFenceStatus

在范围外

stayed → const GenFenceStatus

停留(在范围内超过10分钟)

locFailed → const GenFenceStatus

android 定位失败时,围栏状态无法进行检测

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<GenFenceStatus>
A constant List of the values in this enum, in order of their declaration.