LockscreenVisibility enum

Inheritance
Available extensions

Values

public → const LockscreenVisibility

在锁屏界面上显示通知的全部内容。

const LockscreenVisibility(1)
private → const LockscreenVisibility

默认值,只显示通知的基本信息,隐藏敏感内容。

const LockscreenVisibility(0)
secret → const LockscreenVisibility

在锁屏界面上隐藏通知的全部内容。

const LockscreenVisibility(-1)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<LockscreenVisibility>
A constant List of the values in this enum, in order of their declaration.