NotificationImportance enum
Values
- none → const NotificationImportance
-
默认重要性级别,会有声音和震动。
const NotificationImportance(3) - high → const NotificationImportance
-
高重要性级别,会有声音和震动,并且会以横幅形式显示在屏幕上。
const NotificationImportance(4) - low → const NotificationImportance
-
低重要性级别,只会在状态栏显示通知图标,不会打扰用户。
const NotificationImportance(2) - min → const NotificationImportance
-
最低重要性级别,不会发出声音、震动或者显示任何提示。
const NotificationImportance(1)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
NotificationImportance> - A constant List of the values in this enum, in order of their declaration.