CoordinateConverterResult class
Constructors
Properties
- code → CoordinateConverterResultCode?
-
0 成功 1 Exception 2 无效坐标
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latLng → LatLng?
-
转换后的经纬度
final
- message → String?
-
Exception 时,返回错误信息
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited